Struct commitlog::Message [] [src]

pub struct Message { /* fields omitted */ }

Messages are appended to the log with the following encoding:

Bytes Encoding Value
0-7 Big Endian u64 Offset
8-11 Big Endian u32 Payload Size
12-15 Big Endian u32 CRC32 (IEEE)
16+ Payload

Methods

impl Message
[src]

Creates a new message with a given payload and offset.

Reads a single message.

Serialized representation of the message, in bytes.

IEEE CRC32 of the payload.

Size of the payload.

Offset of the message in the log.

Payload of the message.